@@ -2,7 +2,7 @@
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: rockchalk.Rnw:16-17
+### code chunk number 1: rockchalk.Rnw:17-18
 ###################################################
   if(exists(".orig.enc")) options(encoding = .orig.enc)
 
@@ -16,13 +16,13 @@ options(useFancyQuotes = FALSE)
 
 
 ###################################################
-### code chunk number 3: rockchalk.Rnw:198-199
+### code chunk number 3: rockchalk.Rnw:187-188
 ###################################################
 library(rockchalk)
 
 
 ###################################################
-### code chunk number 4: rockchalk.Rnw:205-208
+### code chunk number 4: rockchalk.Rnw:194-197
 ###################################################
 library(car)
 data(Chile)
@@ -30,26 +30,26 @@ data(Chile)
 
 
 ###################################################
-### code chunk number 5: rockchalk.Rnw:222-223
+### code chunk number 5: rockchalk.Rnw:211-212
 ###################################################
 centralValues(Chile)
 
 
 ###################################################
-### code chunk number 6: rockchalk.Rnw:240-241
+### code chunk number 6: rockchalk.Rnw:229-230
 ###################################################
 m1 <- lm(statusquo ~ age + income + population + region + sex, data = Chile)
 
 
 ###################################################
-### code chunk number 7: rockchalk.Rnw:247-249
+### code chunk number 7: rockchalk.Rnw:236-238
 ###################################################
 m1pred <- predictOMatic(m1)
 m1pred
 
 
 ###################################################
-### code chunk number 8: rockchalk.Rnw:280-286
+### code chunk number 8: rockchalk.Rnw:269-275
 ###################################################
 mypred2 <- predictOMatic(m1, predVals = c("age", "region"), n = 3)
 mypred2
@@ -60,35 +60,35 @@ mypred4
 
 
 ###################################################
-### code chunk number 9: rockchalk.Rnw:307-309
+### code chunk number 9: rockchalk.Rnw:296-298
 ###################################################
 mynewdf <- newdata(m1, predVals = c("age","region"), n = 3)
 mynewdf
 
 
 ###################################################
-### code chunk number 10: rockchalk.Rnw:312-314
+### code chunk number 10: rockchalk.Rnw:301-303
 ###################################################
 mynewdf2 <- newdata(m1, predVals = list(age = "std.dev.", region = c("SA", "C","N")))
 mynewdf2
 
 
 ###################################################
-### code chunk number 11: rockchalk.Rnw:317-319
+### code chunk number 11: rockchalk.Rnw:306-308
 ###################################################
 mynewdf3 <- newdata(m1, predVals = list(age = c(20, 30, 40), region = c("SA", "C","N")))
 mynewdf3
 
 
 ###################################################
-### code chunk number 12: rockchalk.Rnw:324-326
+### code chunk number 12: rockchalk.Rnw:313-315
 ###################################################
 mynewdf <- newdata(m1, predVals = list(age = getFocal(Chile$age, n = 3), region = getFocal(Chile$region, n = 3)))
 mynewdf
 
 
 ###################################################
-### code chunk number 13: rockchalk.Rnw:349-354
+### code chunk number 13: rockchalk.Rnw:339-344
 ###################################################
 df <- data.frame(ldose = rep(0:5, 2), sex = factor(rep(c("M", "F"), c(6, 6))), 
 	SF.numdead = c(1, 4, 9, 13, 18, 20, 0, 2, 6, 10, 12, 16))      
@@ -98,16 +98,21 @@ predictOMatic(budworm.lg, predVals = c(ldose = "std.dev.", sex = "table"), inter
 
 
 ###################################################
-### code chunk number 14: createdata1
+### code chunk number 14: rockchalk.Rnw:360-361
 ###################################################
-set.seed(1234)
-dat <- genCorrelatedData2(N = 100, means = c(0, 10, 0), sds = c(1, 2, 1), rho = c(0, 0, 0), 
-  	stde = 10, beta = c(0, -3, 4, 0), verbose = FALSE)
+descriptiveTable(m1, digits=6)
 
 
 ###################################################
 ### code chunk number 15: createdata1
 ###################################################
+set.seed(1234)
+dat <- genCorrelatedData3(N = 100, means = c(x1 = 0, x2 = 10, x3 = 0), sds = c(1, 2, 1), rho = c(0, 0, 0), stde = 10, beta = c(0, -3, 4, 0), verbose = FALSE)
+
+
+###################################################
+### code chunk number 16: createdata1
+###################################################
 m1 <- lm(y ~ x1 + x2, data = dat)
 m2 <- lm(y ~ x2, data = dat)
 m3 <- lm(y ~ x1 + x2 + x3, data = dat)
@@ -118,50 +123,50 @@ gm1 <- glm(y3 ~ x1 + x2, data = dat)
 
 
 ###################################################
-### code chunk number 16: outreg10
+### code chunk number 17: outreg10
 ###################################################
-or <- outreg(list(m1, m2, m3))
+or <- outreg(list(m1, m2, m3), centering = "siunitx")
 
 
 ###################################################
-### code chunk number 17: outreg20
+### code chunk number 18: outreg20
 ###################################################
-or1 <- outreg(list("The First Model with a Long Title" = m1, "Another Model" = m3), tight = FALSE, alpha = c(0.05, 0.01, 0.001))
+or1 <- outreg(list("The First Model with a Long Title" = m1, "Another Model" = m3), tight = FALSE, alpha = c(0.05, 0.01, 0.001), centering = "siunitx")
 
 
 ###################################################
-### code chunk number 18: outreg70
+### code chunk number 19: outreg70
 ###################################################
 or2 <- outreg(list(m1,gm1), modelLabels = c("OLS:y","GLM: Categorized y"))
 
 
 ###################################################
-### code chunk number 19: ps05
+### code chunk number 20: ps05
 ###################################################
 m1ps <- plotSlopes(m1, plotx = "x2", xlab = "x2 from model m1", interval = "confidence", opacity = 80, col = "red", ylim = c(20, 70))
 
 
 ###################################################
-### code chunk number 20: rockchalk.Rnw:486-487 (eval = FALSE)
+### code chunk number 21: rockchalk.Rnw:507-508 (eval = FALSE)
 ###################################################
 ## m1ps <- plotSlopes(m1, plotx = "x2", xlab = "x2 from model m1", interval = "confidence", opacity = 80, col = "red", ylim = c(20, 70))
 
 
 ###################################################
-### code chunk number 21: rockchalk.Rnw:501-502
+### code chunk number 22: rockchalk.Rnw:522-523
 ###################################################
 m1ps$newdata[1:3, ]
 
 
 ###################################################
-### code chunk number 22: ps09
+### code chunk number 23: ps09
 ###################################################
 dat$y4 <- 1 + 0.1 * dat$x1 - 6.9 * dat$x2 + 0.5 * dat$x1*dat$x2 + 0.2 * dat$x3 + rnorm(100, m = 0, sd = 10)
 m4 <- lm(y4 ~ x1*x2 + x3, data = dat)
 
 
 ###################################################
-### code chunk number 23: ps10
+### code chunk number 24: ps10
 ###################################################
 par(mfcol=c(2,1))
 m4psa <- plotSlopes(m4, plotx = "x1", modx = "x2", xlab = "x1 is a fun plotx")
@@ -170,7 +175,7 @@ par(mfcol=c(1,1))
 
 
 ###################################################
-### code chunk number 24: rockchalk.Rnw:539-540 (eval = FALSE)
+### code chunk number 25: rockchalk.Rnw:560-561 (eval = FALSE)
 ###################################################
 ## par(mfcol=c(2,1))
 ## m4psa <- plotSlopes(m4, plotx = "x1", modx = "x2", xlab = "x1 is a fun plotx")
@@ -179,7 +184,7 @@ par(mfcol=c(1,1))
 
 
 ###################################################
-### code chunk number 25: rockchalk.Rnw:556-560
+### code chunk number 26: rockchalk.Rnw:577-581
 ###################################################
 fourCat <- gl(4,25, labels=c("East","West","South", "Midwest"))
 dat$x4 <- sample(fourCat, 100, replace = TRUE)
@@ -188,110 +193,110 @@ m5 <- lm (y5 ~ x1*x4 + x3, data=dat)
 
 
 ###################################################
-### code chunk number 26: ps20
+### code chunk number 27: ps20
 ###################################################
 m5psa <- plotSlopes(m5, plotx = "x1", modx = "x4", xlab = "x1 is a Continuous Predictor", xlim = magRange(dat$x1, c(1.2,1)))
 
 
 ###################################################
-### code chunk number 27: ps21
+### code chunk number 28: ps21
 ###################################################
 m5psb <- plotSlopes(m5, plotx = "x1", modx = "x4", modxVals = c("West","East"), xlab = "x1 is a Continuous Predictor", xlim=magRange(dat$x1, c(1.2,1)), interval = "conf")
 
 
 ###################################################
-### code chunk number 28: rockchalk.Rnw:584-585 (eval = FALSE)
+### code chunk number 29: rockchalk.Rnw:604-605 (eval = FALSE)
 ###################################################
 ## m5psa <- plotSlopes(m5, plotx = "x1", modx = "x4", xlab = "x1 is a Continuous Predictor", xlim = magRange(dat$x1, c(1.2,1)))
 
 
 ###################################################
-### code chunk number 29: rockchalk.Rnw:596-597 (eval = FALSE)
+### code chunk number 30: rockchalk.Rnw:616-617 (eval = FALSE)
 ###################################################
 ## m5psb <- plotSlopes(m5, plotx = "x1", modx = "x4", modxVals = c("West","East"), xlab = "x1 is a Continuous Predictor", xlim=magRange(dat$x1, c(1.2,1)), interval = "conf")
 
 
 ###################################################
-### code chunk number 30: ts10
+### code chunk number 31: ts10
 ###################################################
 m4psats <- testSlopes(m4psa)
 plot(m4psats)
 
 
 ###################################################
-### code chunk number 31: rockchalk.Rnw:701-702
+### code chunk number 32: rockchalk.Rnw:720-721
 ###################################################
 dat$y5 <- with(dat, -3*x1 + 15*log(0.1 + x2 - min(x2)) + 1.1*x2 + 8.2 *x1 * x2 + 10*rnorm(100))
 
 
 ###################################################
-### code chunk number 32: pcps20
+### code chunk number 33: pcps20
 ###################################################
 m5 <- lm(y5 ~ log(x2) + x1 * x2, data = dat)
 m5pc <- plotCurves(m5, plotx = "x2", modx = "x1")
 
 
 ###################################################
-### code chunk number 33: rockchalk.Rnw:717-718 (eval = FALSE)
+### code chunk number 34: rockchalk.Rnw:735-736 (eval = FALSE)
 ###################################################
 ## m5 <- lm(y5 ~ log(x2) + x1 * x2, data = dat)
 ## m5pc <- plotCurves(m5, plotx = "x2", modx = "x1")
 
 
 ###################################################
-### code chunk number 34: pp100
+### code chunk number 35: pp100
 ###################################################
 p100 <- plotPlane(m4, plotx1 = "x1", plotx2 = "x2", phi = 10, theta = -80, lcol = gray(.70))
 
 
 ###################################################
-### code chunk number 35: rockchalk.Rnw:752-753 (eval = FALSE)
+### code chunk number 36: rockchalk.Rnw:769-770 (eval = FALSE)
 ###################################################
 ## p100 <- plotPlane(m4, plotx1 = "x1", plotx2 = "x2", phi = 10, theta = -80, lcol = gray(.70))
 
 
 ###################################################
-### code chunk number 36: pp111
+### code chunk number 37: pp111
 ###################################################
 ppm5 <- plotPlane(m5, plotx1 = "x2", plotx2 = "x1", phi = 0, npp = 15, lcol = gray(.80))
 addLines(from = m5pc, to = ppm5, col = m5pc$col)
 
 
 ###################################################
-### code chunk number 37: rockchalk.Rnw:800-802
+### code chunk number 38: rockchalk.Rnw:817-819
 ###################################################
 m4 <- lm (y4 ~ x1 * x2, data = dat)
 m4s <- standardize(m4)
 
 
 ###################################################
-### code chunk number 38: rockchalk.Rnw:808-809
+### code chunk number 39: rockchalk.Rnw:825-826
 ###################################################
 summary(m4s)
 
 
 ###################################################
-### code chunk number 39: stdreg10
+### code chunk number 40: stdreg10
 ###################################################
 or10 <- outreg(list(m4, m4s), tight = F, modelLabels = c("Not Standardized","Standardized"))
 
 
 ###################################################
-### code chunk number 40: rockchalk.Rnw:855-857
+### code chunk number 41: rockchalk.Rnw:872-874
 ###################################################
 m4mc <- meanCenter(m4)
 summary(m4mc)
 
 
 ###################################################
-### code chunk number 41: rockchalk.Rnw:890-892
+### code chunk number 42: rockchalk.Rnw:907-909
 ###################################################
 m4rc <- residualCenter(m4)
 summary(m4rc)
 
 
 ###################################################
-### code chunk number 42: rockchalk.Rnw:1034-1039
+### code chunk number 43: rockchalk.Rnw:1051-1056
 ###################################################
 dat2 <- genCorrelatedData(N=400, rho=.4, stde=300, beta=c(2,0.1,0.1,0.2))
 m6linear <- lm (y ~ x1 + x2, data=dat2)
@@ -301,13 +306,13 @@ m6rc <- residualCenter(m6int)
 
 
 ###################################################
-### code chunk number 43: mcenter10
+### code chunk number 44: mcenter10
 ###################################################
 or11 <- outreg(list(m6linear, m6int, m6mc, m6rc), tight=F, modelLabels=c("Linear", "Interaction","Mean-centered","Residual-centered"), alpha = c(0.05, 0.01))
 
 
 ###################################################
-### code chunk number 44: pscenter
+### code chunk number 45: pscenter
 ###################################################
 par(mfcol = c(2, 1))
 plotSlopes(m6int, plotx = "x1", modx = "x2", modxVals = "std.dev.",  n = 2, interval = "confidence", main= "Not Centered")
@@ -316,7 +321,7 @@ par(mfcol = c(1, 1))
 
 
 ###################################################
-### code chunk number 45: mcenter50
+### code chunk number 46: mcenter50
 ###################################################
 op <- par(no.readonly = TRUE)
 par(mfcol=c(2,2))
@@ -329,7 +334,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 46: rcenter40
+### code chunk number 47: rcenter40
 ###################################################
 dat3 <- centerNumerics(dat2)
 ##m6mcpred <- fitted(m6mc) ##
